@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -33,16 +33,19 @@ static conf_param_t params_clnt[] = {
 	{ "PID_FILE", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_PIDFILE},
 	{ "SERVER", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SERVER},
 	{ "SERVER_PORT", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SRVPORT},
+	{ "REGISTRAR_PORT", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_REGPORT},
+	{ "ALLOW_FROM", STRING, {0}, check_netlist, 0, ""},
 	{ "AGENT_PORT", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_AGTPORT},
+	{ "ADDRESS_FAMILY", STRING, {0}, check_addrfamily, 0, SCHEDWI_DEFAULT_ADDRESS_FAMILY},
 	{ "IFACE_LISTEN", STRING, {0}, 0, 0, 0},
 	{ "RESULT_DIR", STRING, {0}, check_dirname, 0, SCHEDWI_DEFAULT_RESULTDIR},
 	{ "RESULT_PREFIX", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_RESULTPREFIX},
 	{ "RESULT_SUFFIX", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_RESULTSUFFIX},
 	{ "SSLEngine", BOOL, {0}, check_bool, 0, SCHEDWI_DEFAULT_SSL_ENGINE},
-	{ "SSLClientCertificateFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_CLIENT_CERTIFICATE_FILE},
-	{ "SSLClientCertificateKeyFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_CLIENT_CERTIFICATE_KEY_FILE},
-	{ "SSLServerCertificateFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_SERVER_CERTIFICATE_FILE},
-	{ "SSLQuickRandom", BOOL, {0}, check_bool, 0, 0},
+	{ "SSLCertificateFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_CLIENT_CERTIFICATE_FILE},
+	{ "SSLCertificateKeyFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_CLIENT_CERTIFICATE_KEY_FILE},
+	{ "SSLCACertificateFile", STRING, {0}, 0, 0, SCHEDWI_DEFAULT_SSL_SERVER_CERTIFICATE_FILE},
+	{ "SSLQuickRandom", BOOL, {0}, check_bool, 0, "1"},
 	{ 0, INT, {0}, 0, 0, 0}
 };
 
