@@ -107,6 +107,7 @@ init_job_run (job_run_t *j)
 		j->cgroup_name = NULL;
 		j->work = NULL;
 		j->shell = NULL;
+		j->detach = 0;
 		j->uid = SCHEDWI_UID_NOBODY;
 		j->gid = SCHEDWI_GID_NOGROUP;
 		j->mask = SCHEDWI_DEFAULT_UMASK;
@@ -842,6 +843,23 @@ add_cgroup_job_run (job_run_t *j, const char *cgroup_name)
 }
 
 
+/*
+ * Store the detach mode flag.
+ *
+ * Return:
+ *    Always 0
+ */
+int
+add_detach_job_run (job_run_t *j, int detach)
+{
+	if (j == NULL) {
+		return 0;
+	}
+	j->detach = detach;
+	return 0;
+}
+
+
 /*
  * Compose the program string to run and the arguments.
  * If `load_env' is 0, the provided command will be directly executed.
