@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -40,7 +40,7 @@ struct modules {
 
 static struct modules *module_array = NULL;
 static size_t module_array_size = 0;
-static int module_array_idx = 0;
+static unsigned int module_array_idx = 0;
 
 
 /*
@@ -56,33 +56,6 @@ build_module_name_static (const char *module_name, char buffer[])
 }
 
 
-/*
- * Construct the buffer containing the module name.  This buffer must then
- * be sent to the remote socket
- *
- * Return:
- *   The size of the buffer (which must be freed by the caller) or
- *   -1 in case of memory allocation error
- */
-ssize_t
-build_module_name (const char *module_name, char **buffer)
-{
-	char *ret;
-
-#if HAVE_ASSERT_H
-	assert (buffer != NULL);
-#endif
-
-	ret = (char *) malloc (SCHEDWI_NET_FUNCTION_LENGHT);
-	if (ret == NULL) {
-		return -1;
-	}
-	build_module_name_static (module_name, ret);
-	*buffer = ret;
-	return SCHEDWI_NET_FUNCTION_LENGHT;
-}
-
-
 /*
  * Return the function associated this the provided module name
  *
@@ -93,7 +66,7 @@ build_module_name (const char *module_name, char **buffer)
 int
 (*net_module (const char *module_name))(net_id *, char *, size_t)
 {
-	int i;
+	unsigned int i;
 
 	if (module_name == NULL || module_array == NULL) {
 		return NULL;
@@ -138,7 +111,7 @@ add_module (const char *module_name, int (*module)(net_id *, char *, size_t))
 	}
 	module_array[module_array_idx].function = module;
 	build_module_name_static (	module_name,
-					module_array[module_array_idx].name); 
+					module_array[module_array_idx].name);
 	module_array_idx++;
 	return 0;
 }
