@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -24,10 +24,6 @@
 
 #include <schedwi.h>
 
-#if HAVE_SYS_TYPES_H
-#include <sys/types.h>
-#endif
-
 #include <net_utils_glob.h>
 
 /* Allow the use in C++ code.  */
@@ -40,7 +36,6 @@ extern int (*net_module OF((const char *module_name)))
 extern int add_module OF((	const char *module_name,
 				int (*module)(net_id *, char *, size_t)));
 extern void destroy_modules OF(());
-extern ssize_t build_module_name OF((const char *module_name, char **buffer));
 
 #ifdef __cplusplus
 }
