@@ -60,6 +60,7 @@ enum steps {
 	S_KEY_ARGS,
 	S_ARG_ARRAY_START,
 	S_KEY_USERENV,
+	S_KEY_DETACH,
 	S_KEY_ENV,
 	S_ENV_ARRAY_START,
 	S_END
@@ -193,12 +194,20 @@ json_char_callback (void* ctx, int type, const JSON_value* value)
 				add_loadenv_job_parameters (&(s->job), 1);
 				s->step = S_DATA;
 			}
+			else if (s->step == S_KEY_DETACH) {
+				add_detach_job_parameters (&(s->job), 1);
+				s->step = S_DATA;
+			}
 			break;
 		case JSON_T_FALSE:
 			if (s->step == S_KEY_USERENV) {
 				add_loadenv_job_parameters (&(s->job), 0);
 				s->step = S_DATA;
 			}
+			else if (s->step == S_KEY_DETACH) {
+				add_detach_job_parameters (&(s->job), 0);
+				s->step = S_DATA;
+			}
 			break;
 		case JSON_T_OBJECT_BEGIN:
 			if (s->step == S_OUTER_ARRAY_MODULE) {
@@ -249,6 +258,12 @@ json_char_callback (void* ctx, int type, const JSON_value* value)
 					s->step = S_KEY_USERENV;
 				}
 				else
+				if (schedwi_strcasecmp (value->vu.str.value,
+							"detach") == 0)
+				{
+					s->step = S_KEY_DETACH;
+				}
+				else
 				if (schedwi_strcasecmp (value->vu.str.value,
 							"args") == 0)
 				{
@@ -324,7 +339,7 @@ int
 run_job (net_id *sock, char *buffer, size_t size)
 {
 	char *err_msg, *s;
-	int ret, i;
+	int ret, i, detach;
         JSON_config config;
         struct JSON_parser_struct *jc;
 	struct json_cb cb_data;
@@ -438,6 +453,7 @@ run_job (net_id *sock, char *buffer, size_t size)
 
 	/* Start the job */
 	ret = submit_job (&(cb_data.job), cb_data.jobid, &child, &err_msg);
+	detach = cb_data.job.detach;
 	destroy_job_parameters (&(cb_data.job));
 	if (ret != 0) {
 		s = "{ \"success\" : false, \"data\" : \"";
@@ -458,12 +474,20 @@ run_job (net_id *sock, char *buffer, size_t size)
 		return (ret == -2) ? -3: ret;
 	}
 	else {
-		lwc_writeLog (	LOG_INFO, _("Job %s: Started (PID %d)"),
-				cb_data.jobid, child);
+		if (detach == 0) {
+			lwc_writeLog (	LOG_INFO,
+					_("Job %s: Started (PID %d)"),
+					cb_data.jobid, child);
+		}
+		else {
+			lwc_writeLog (	LOG_INFO,
+					_("Job %s: Started (detached)"),
+					cb_data.jobid);
+		}
 	}
 
-	/* Add the job to the list of the running jobs */
-	if (add_child (child, cb_data.jobid) != 0) {
+	/* Add the job to the list of the running jobs (if not detached) */
+	if (detach == 0 && add_child (child, cb_data.jobid) != 0) {
 		lwc_writeLog (LOG_CRIT, _("Memory allocation error"));
 	}
 	free (cb_data.jobid);
