@@ -1,6 +1,6 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -42,7 +42,8 @@
 int
 get_version (net_id *sock, char *buffer, size_t size)
 {
-	net_write (sock, PACKAGE_VERSION, schedwi_strlen (PACKAGE_VERSION));
+	char *s = "{ \"success\" : true, \"data\" : \"" PACKAGE_VERSION "\" }";
+	net_write (sock, s, schedwi_strlen (s));
 	return 0;
 }
 
