@@ -1,6 +1,6 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
-     
+   Copyright (C) 2007-2010 Herve Quatremain
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -43,24 +43,25 @@
  *             in /etc/services)
  *       iface is the network interface to listen to (NULL or empty means all
  *             the interfaces)
+ * address_family is the address family (any, inet or inet6)
  *
  * Return:
  *   0 --> No error (the network descriptor in id is set)
  *  -1 --> Error (an error message is displayed using lwc_writeLog())
  */
 int
-net_server (net_id *id, const char *port_number, const char *iface)
+net_server (net_id *id, const char *port_number, const char *iface,
+		const char *address_family)
 {
 #if HAVE_ASSERT_H
 	assert (id != (net_id *)0);
 #endif
 
-	id->sock = net_server_sock (port_number, iface);
-	if (id->sock < 0) {
-		return -1;
-	}
-
-	return 0;
+	id->sock = -1;
+	id->sock_max = -1;
+	FD_ZERO (&(id->sock_set));
+	return net_server_sock (port_number, iface, address_family,
+					&(id->sock_set), &(id->sock_max));
 }
 
 
@@ -77,13 +78,17 @@ net_server (net_id *id, const char *port_number, const char *iface)
  *  -1 --> Error (a message is displayed using lwc_writeLog())
  */
 int
-net_accept (net_id *id, net_id *new_id, const char *schedwi_server_name)
+net_accept (	net_id *id, net_id *new_id,
+		const char *schedwi_server_name, const char *allow_from)
 {
 #if HAVE_ASSERT_H
 	assert (id != (net_id *)0 && new_id != (net_id *)0);
 #endif
 
-	new_id->sock = net_accept_sock (id->sock, schedwi_server_name);
+	new_id->sock_max = -1;
+	FD_ZERO (&(new_id->sock_set));
+	new_id->sock = net_accept_sock (&(id->sock_set), id->sock_max,
+					allow_from);
 	if (new_id->sock < 0) {
 		return -1;
 	}
@@ -96,6 +101,7 @@ net_accept (net_id *id, net_id *new_id, const char *schedwi_server_name)
 					schedwi_server_name);
 		if (ret != 0) {
 			net_close_sock (new_id->sock);
+			new_id->sock = -1;
 		}
 		return ret;
 	}
@@ -123,6 +129,8 @@ net_client (net_id *id, const char *port_number, const char *hostname)
 	assert (id != (net_id *)0);
 #endif
 
+	id->sock_max = -1;
+	FD_ZERO (&(id->sock_set));
 	id->sock = net_client_sock (port_number, hostname);
 	if (id->sock < 0) {
 		return -1;
@@ -132,6 +140,7 @@ net_client (net_id *id, const char *port_number, const char *hostname)
 	if (ssl_enabled () != 0) {
 		if (net_client_ssl (id->sock, &(id->session), hostname) != 0) {
 			net_close_sock (id->sock);
+			id->sock = -1;
 			return -1;
 		}
 	}
@@ -173,10 +182,12 @@ net_read (net_id *id, char **buff, size_t *len)
 /*
  * Read the reply
  *
- * The format of the reply must be as follow:
- *    The first character: '0' means success, an other character means failure
- *    The next characters: An optional explanation message (which is returned
- *                         in result_msg)
+ * The format of the JSON reply looks like:
+ *     {
+ *         "success" : false,
+ *          "data" : "Database unavailable"
+ *     }
+ *
  * No reply (nothing to read) means failure.
  *
  * Return:
@@ -233,29 +244,6 @@ net_write (net_id *id, const char *buff, size_t len)
 }
 
 
-/*
- * Write the End of Request tag
- *
- * Return:
- *   0 --> No error
- *  -1 --> Write error (a message is displayed using lwc_writeLog())
- */
-int
-net_write_eof (net_id *id)
-{
-	if (id != (net_id *)0) {
-		if (ssl_enabled () == 0) {
-			return net_write_eof_sock (id->sock);
-		}
-
-#if HAVE_LIBGNUTLS
-		return net_write_eof_ssl (id->session);
-#endif
-	}
-	return 0;
-}
-
-
 /*
  * Close the network descriptor
  */
@@ -266,6 +254,14 @@ net_close (net_id *id)
 		return 0;
 	}
 
+	while (id->sock_max > 0) {
+		if (FD_ISSET (--(id->sock_max), &(id->sock_set)) != 0) {
+			net_close_sock (id->sock_max);
+		}
+	}
+	FD_ZERO (&(id->sock_set));
+	id->sock_max = -1;
+
 	if (ssl_enabled () == 0) {
 		return net_close_sock (id->sock);
 	}
