@@ -1,6 +1,6 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
-     
+   Copyright (C) 2007-2010 Herve Quatremain
+
    This file is part of Schedwi.
 
    Schedwi is free software; you can redistribute it and/or modify
@@ -33,8 +33,10 @@ extern "C" {
 #endif
 
 extern int send_process_start OF(());
-extern void send_process_wakeup OF(());
 extern void send_process_stop OF(());
+extern void send_process_wakeup OF(());
+extern void send_process_term OF(());
+extern void send_process_kill OF(());
 
 #ifdef __cplusplus
 }
