@@ -1,5 +1,5 @@
 /* Schedwi
-   Copyright (C) 2007 Herve Quatremain
+   Copyright (C) 2007-2010 Herve Quatremain
 
    This file is part of Schedwi.
 
@@ -24,7 +24,7 @@
  *     1) The absolute path of an existing file
  *
  * Output:
- *     stdout) The result of the command execution send by the schedwiclnt
+ *     stdout) The result of the command execution send by schedwiclnt
  *
  * Return:
  *   0 on success or
@@ -118,6 +118,59 @@ schedwi_strlen (const char *s)
 }
 
 
+/*
+ * strncmp -- compare two strings
+ */
+int
+schedwi_strncmp (const char *s1, const char *s2, unsigned int n)
+{
+	unsigned int i;
+
+	if (s1 == 0) {
+		if (s2 == 0) {
+			return 0;
+		}
+		return -1;
+	}
+	if (s2 == 0) {
+		return 1;
+	}
+
+	for (	i = 0;
+		   i < n
+		&& s1[i] != '\0' && s2[i] != '\0'
+		&& s1[i] == s2[i];
+		i++);
+	return (i == n) ? 0 : s1[i] - s2[i];
+}
+
+
+/*
+ * strnstr - locate a substring in the first n characters
+ */
+char *
+schedwi_strnstr (char *haystack, const char *needle, unsigned int n)
+{
+	unsigned int len;
+
+	if (needle == 0 || *needle == '\0' || haystack == 0) {
+		return 0;
+	}
+
+	len = schedwi_strlen (needle);
+
+	while (len <= n) {
+		if (schedwi_strncmp (needle, haystack, len) == 0) {
+			return haystack;
+		}
+		n--;
+		haystack++;
+	}
+
+	return 0;
+}
+
+
 /*
  * atoi - convert a string to an integer (very simplified version)
  */
@@ -152,7 +205,7 @@ send_testfile (const char *path_to_file)
 {
 	int sock;
 	struct sockaddr_in sad;
-	char buff[4096];
+	char buff[4096], *s;
 	char result;
 	ssize_t nb_read;
 	struct hostent *he;
@@ -182,37 +235,19 @@ send_testfile (const char *path_to_file)
 	}
 
 	/* Build and send the header */
-	schedwi_memset (buff, 0, 25);
-	buff[0] = 't';
-	buff[1] = 'e';
-	buff[2] = 's';
-	buff[3] = 't';
-	buff[4] = 'f';
-	buff[5] = 'i';
-	buff[6] = 'l';
-	buff[7] = 'e';
-	buff[8] = '-';
-	buff[9] = '0';
-	buff[10] = '.';
-	buff[11] = '1';
-	send (sock, buff, 25, 0);
-
-	/* Send the file name to test */
-	send (sock, "FIL:$FILE_NAME\n", 15, 0);
-
-	/* Send the environment */
-	send (sock, "ENV:1:A:1\n", 10, 0); 
-	send (sock, "ENV:2:B:2\n", 10, 0); 
-	send (sock, "ENV:3:C:foo\n", 12, 0); 
-	send (sock, "ENV:4:CMD:$C\n", 13, 0); 
-	send (sock, "ENV:5:FILE_NAME:", 16, 0); 
+	s = "[ \"testfile\", \
+	       { \
+	         \"file\"   : \"$FILE_NAME\", \
+	         \"job id\" : \"20070324_10\", \
+	         \"env\"    : [ \"A=1\", \"B=2\", \"C=foo\", \"CMD=$C\", \
+	                        \"FILE_NAME=";
+	send (sock, s, schedwi_strlen (s), 0);
 	send (sock, path_to_file, schedwi_strlen (path_to_file), 0);
-	send (sock, "\n", 1, 0);
-
-	send (sock, "\nbYe", 4, 0);
+	s = "\" ] } ]";
+	send (sock, s, schedwi_strlen (s), 0);
 
 	/* Read the reply and dump it to stdout */
-	result = 0;
+	result = 1;
 	do{
 		nb_read = recv (sock, buff, 4096, 0);
 		if (nb_read == 0) {
@@ -222,15 +257,17 @@ send_testfile (const char *path_to_file)
 			closesocket (sock);
 			return 11;
 		}
-		if (result == 0) {
-			result = buff[0];
+		if (result == 1) {
+			if (schedwi_strnstr (buff, "true", nb_read) != NULL) {
+				result = 0;
+			}
 		}
 		write (1, buff, nb_read);
 	} while (1);
 
 	closesocket (sock);
 
-	if (result != '0') {
+	if (result != 0) {
 		return 12;
 	}
 	return 0;
